Class: IbmCloudGlobalTagging::AttachTagRequest

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/ibm_cloud_global_tagging/models/attach_tag_request.rb

Overview

A list of resources to attach tags to, or a valid Global Search string that dynamically identifies the resources to attach tags to. In that case the query cannot resolve to more than 100 resources, otherwise the entire operation will fail. The caller must have the permission to manage tags on those resources. The operation will fail for the other resources and a specific error is returned in the operation response.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ AttachTagRequest

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
# File 'lib/ibm_cloud_global_tagging/models/attach_tag_request.rb', line 68

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `IbmCloudGlobalTagging::AttachTagRequest` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `IbmCloudGlobalTagging::AttachTagRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'tag_name')
    self.tag_name = attributes[:'tag_name']
  end

  if attributes.key?(:'tag_names')
    if (value = attributes[:'tag_names']).is_a?(Array)
      self.tag_names = value
    end
  end

  if attributes.key?(:'resources')
    if (value = attributes[:'resources']).is_a?(Array)
      self.resources = value
    end
  end

  if attributes.key?(:'query')
    self.query = attributes[:'query']
  end
end

Instance Attribute Details

#queryObject

Returns the value of attribute query.



28
29
30
# File 'lib/ibm_cloud_global_tagging/models/attach_tag_request.rb', line 28

def query
  @query
end

#resourcesObject

List of resources on which the tagging operation operates on



26
27
28
# File 'lib/ibm_cloud_global_tagging/models/attach_tag_request.rb', line 26

def resources
  @resources
end

#tag_nameObject

The name of the tag to attach



20
21
22
# File 'lib/ibm_cloud_global_tagging/models/attach_tag_request.rb', line 20

def tag_name
  @tag_name
end

#tag_namesObject

An array of tag names to attach



23
24
25
# File 'lib/ibm_cloud_global_tagging/models/attach_tag_request.rb', line 23

def tag_names
  @tag_names
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



41
42
43
# File 'lib/ibm_cloud_global_tagging/models/attach_tag_request.rb', line 41

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



46
47
48
# File 'lib/ibm_cloud_global_tagging/models/attach_tag_request.rb', line 46

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



31
32
33
34
35
36
37
38
# File 'lib/ibm_cloud_global_tagging/models/attach_tag_request.rb', line 31

def self.attribute_map
  {
    :'tag_name' => :'tag_name',
    :'tag_names' => :'tag_names',
    :'resources' => :'resources',
    :'query' => :'query'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
# File 'lib/ibm_cloud_global_tagging/models/attach_tag_request.rb', line 230

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



61
62
63
64
# File 'lib/ibm_cloud_global_tagging/models/attach_tag_request.rb', line 61

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



51
52
53
54
55
56
57
58
# File 'lib/ibm_cloud_global_tagging/models/attach_tag_request.rb', line 51

def self.openapi_types
  {
    :'tag_name' => :'String',
    :'tag_names' => :'Array<String>',
    :'resources' => :'Array<Resource>',
    :'query' => :'QueryString'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



206
207
208
209
210
211
212
213
# File 'lib/ibm_cloud_global_tagging/models/attach_tag_request.rb', line 206

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      tag_name == o.tag_name &&
      tag_names == o.tag_names &&
      resources == o.resources &&
      query == o.query
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


217
218
219
# File 'lib/ibm_cloud_global_tagging/models/attach_tag_request.rb', line 217

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



223
224
225
# File 'lib/ibm_cloud_global_tagging/models/attach_tag_request.rb', line 223

def hash
  [tag_name, tag_names, resources, query].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
# File 'lib/ibm_cloud_global_tagging/models/attach_tag_request.rb', line 105

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if !@tag_name.nil? && @tag_name.to_s.length > 128
    invalid_properties.push('invalid value for "tag_name", the character length must be smaller than or equal to 128.')
  end

  pattern = Regexp.new(/^[ ]*[A-Za-z0-9:_.\-][A-Za-z0-9 :_.\-]*$/)
  if !@tag_name.nil? && @tag_name !~ pattern
    invalid_properties.push("invalid value for \"tag_name\", must conform to the pattern #{pattern}.")
  end

  if !@tag_names.nil? && @tag_names.length > 100
    invalid_properties.push('invalid value for "tag_names", number of items must be less than or equal to 100.')
  end

  if !@tag_names.nil? && @tag_names.length < 1
    invalid_properties.push('invalid value for "tag_names", number of items must be greater than or equal to 1.')
  end

  if !@resources.nil? && @resources.length > 100
    invalid_properties.push('invalid value for "resources", number of items must be less than or equal to 100.')
  end

  if !@resources.nil? && @resources.length < 1
    invalid_properties.push('invalid value for "resources", number of items must be greater than or equal to 1.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



252
253
254
255
256
257
258
259
260
261
262
263
264
# File 'lib/ibm_cloud_global_tagging/models/attach_tag_request.rb', line 252

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



138
139
140
141
142
143
144
145
146
147
# File 'lib/ibm_cloud_global_tagging/models/attach_tag_request.rb', line 138

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if !@tag_name.nil? && @tag_name.to_s.length > 128
  return false if !@tag_name.nil? && @tag_name !~ Regexp.new(/^[ ]*[A-Za-z0-9:_.\-][A-Za-z0-9 :_.\-]*$/)
  return false if !@tag_names.nil? && @tag_names.length > 100
  return false if !@tag_names.nil? && @tag_names.length < 1
  return false if !@resources.nil? && @resources.length > 100
  return false if !@resources.nil? && @resources.length < 1
  true
end