Class: IbmCloudGlobalTagging::Resource
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- IbmCloudGlobalTagging::Resource
- Defined in:
- lib/ibm_cloud_global_tagging/models/resource.rb
Overview
A resource that might have tags that are attached.
Instance Attribute Summary collapse
-
#resource_id ⇒ Object
The CRN or IMS ID of the resource.
-
#resource_type ⇒ Object
The IMS resource type of the resource.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ Resource
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ Resource
Initializes the object
59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 |
# File 'lib/ibm_cloud_global_tagging/models/resource.rb', line 59 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `IbmCloudGlobalTagging::Resource` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `IbmCloudGlobalTagging::Resource`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'resource_id') self.resource_id = attributes[:'resource_id'] else self.resource_id = nil end if attributes.key?(:'resource_type') self.resource_type = attributes[:'resource_type'] end end |
Instance Attribute Details
#resource_id ⇒ Object
The CRN or IMS ID of the resource
20 21 22 |
# File 'lib/ibm_cloud_global_tagging/models/resource.rb', line 20 def resource_id @resource_id end |
#resource_type ⇒ Object
The IMS resource type of the resource. It can be one of SoftLayer_Virtual_DedicatedHost, SoftLayer_Hardware, SoftLayer_Hardware_Server, SoftLayer_Network_Application_Delivery_Controller, SoftLayer_Network_Vlan, SoftLayer_Network_Vlan_Firewall, SoftLayer_Network_Component_Firewall, SoftLayer_Network_Firewall_Module_Context, SoftLayer_Virtual_Guest
23 24 25 |
# File 'lib/ibm_cloud_global_tagging/models/resource.rb', line 23 def resource_type @resource_type end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
34 35 36 |
# File 'lib/ibm_cloud_global_tagging/models/resource.rb', line 34 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
39 40 41 |
# File 'lib/ibm_cloud_global_tagging/models/resource.rb', line 39 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
26 27 28 29 30 31 |
# File 'lib/ibm_cloud_global_tagging/models/resource.rb', line 26 def self.attribute_map { :'resource_id' => :'resource_id', :'resource_type' => :'resource_type' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 |
# File 'lib/ibm_cloud_global_tagging/models/resource.rb', line 179 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
52 53 54 55 |
# File 'lib/ibm_cloud_global_tagging/models/resource.rb', line 52 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
44 45 46 47 48 49 |
# File 'lib/ibm_cloud_global_tagging/models/resource.rb', line 44 def self.openapi_types { :'resource_id' => :'String', :'resource_type' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
157 158 159 160 161 162 |
# File 'lib/ibm_cloud_global_tagging/models/resource.rb', line 157 def ==(o) return true if self.equal?(o) self.class == o.class && resource_id == o.resource_id && resource_type == o.resource_type end |
#eql?(o) ⇒ Boolean
166 167 168 |
# File 'lib/ibm_cloud_global_tagging/models/resource.rb', line 166 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
172 173 174 |
# File 'lib/ibm_cloud_global_tagging/models/resource.rb', line 172 def hash [resource_id, resource_type].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 |
# File 'lib/ibm_cloud_global_tagging/models/resource.rb', line 86 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @resource_id.nil? invalid_properties.push('invalid value for "resource_id", resource_id cannot be nil.') end if @resource_id.to_s.length > 1024 invalid_properties.push('invalid value for "resource_id", the character length must be smaller than or equal to 1024.') end pattern = Regexp.new(/^(crn:v1(:[^:]*){7}:.*|[a-zA-Z0-9_\-\.]+)$/) if @resource_id !~ pattern invalid_properties.push("invalid value for \"resource_id\", must conform to the pattern #{pattern}.") end pattern = Regexp.new(/^[A-Za-z0-9_ :.-]*$/) if !@resource_type.nil? && @resource_type !~ pattern invalid_properties.push("invalid value for \"resource_type\", must conform to the pattern #{pattern}.") end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
201 202 203 204 205 206 207 208 209 210 211 212 213 |
# File 'lib/ibm_cloud_global_tagging/models/resource.rb', line 201 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
112 113 114 115 116 117 118 119 |
# File 'lib/ibm_cloud_global_tagging/models/resource.rb', line 112 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @resource_id.nil? return false if @resource_id.to_s.length > 1024 return false if @resource_id !~ Regexp.new(/^(crn:v1(:[^:]*){7}:.*|[a-zA-Z0-9_\-\.]+)$/) return false if !@resource_type.nil? && @resource_type !~ Regexp.new(/^[A-Za-z0-9_ :.-]*$/) true end |